# FilterOperator


## Enum

* `Equal` (value: `'eq'`)

* `NotEqual` (value: `'ne'`)

* `Greater` (value: `'gt'`)

* `GreaterEq` (value: `'gte'`)

* `Less` (value: `'lt'`)

* `LessEq` (value: `'lte'`)

* `Like` (value: `'like'`)

* `StartsWith` (value: `'starts'`)

* `EndsWith` (value: `'ends'`)

* `NotLike` (value: `'nlike'`)

* `In` (value: `'in'`)

* `NotIn` (value: `'nin'`)

* `IsNull` (value: `'null'`)

* `IsNotNull` (value: `'nnull'`)

* `DateEqual` (value: `'deq'`)

* `DateAfter` (value: `'dafter'`)

* `DateBefore` (value: `'dbefore'`)

* `DateBetween` (value: `'dbetween'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


